@@ -7,6 +7,11 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2020 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. University of Heidelberg, Heidelberg, Germany
+ *     3. University College London, London, UK
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
@@ -470,7 +475,8 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedMultiAtts,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details, 
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
@@ -478,7 +484,8 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedCoreAtts,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -548,7 +555,8 @@ CompartmentReference::readAttributes (const XMLAttributes& attributes,
   {
     std::string message = "The attribute 'compartment' is missing in the <compartmentReference> element.";
     getErrorLog()->logPackageError("multi", MultiCpaRef_AllowedMultiAtts,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, 
+                   getLine(), getColumn());
   }
 
 }
@@ -618,7 +626,7 @@ ListOfCompartmentReferences::clone () const
 
 /*
  * Get a CompartmentReference from the ListOfCompartmentReferences by index.
-*/
+ */
 CompartmentReference*
 ListOfCompartmentReferences::get(unsigned int n)
 {
